@@ -7,6 +7,7 @@ from mercury_engine_data_structures.file_tree_editor import OutputFormat
 
 from open_dread_rando import elevator, lua_util, game_patches
 from open_dread_rando.cosmetic_patches import apply_cosmetic_patches
+from open_dread_rando.door_patcher import patch_door
 from open_dread_rando.exefs import include_depackager, patch_exefs
 from open_dread_rando.logger import LOG
 from open_dread_rando.lua_editor import LuaEditor
@@ -15,7 +16,7 @@ from open_dread_rando.output_config import output_format_for_category, output_pa
 from open_dread_rando.patcher_editor import PatcherEditor
 from open_dread_rando.pickup import pickup_object_for
 from open_dread_rando.static_fixes import apply_static_fixes
-from open_dread_rando.text_patches import apply_text_patches, patch_hints, patch_text
+from open_dread_rando.text_patches import apply_text_patches, patch_credits, patch_hints, patch_text
 from open_dread_rando.validator_with_default import DefaultValidatingDraft7Validator
 
 T = typing.TypeVar("T")
@@ -76,6 +77,7 @@ def create_custom_init(editor: PatcherEditor, configuration: dict):
         "energy_per_tank": energy_per_tank,
         "energy_per_part": energy_per_part,
         "immediate_energy_parts": configuration.get("immediate_energy_parts", False),
+        "default_x_released": configuration.get("game_patches", {}).get("default_x_released", False),
     }
 
     return lua_util.replace_lua_template("custom_init.lua", replacement)
@@ -137,9 +139,13 @@ def patch_extracted(input_path: Path, output_path: Path, configuration: dict):
     if "hints" in configuration:
         patch_hints(editor, configuration["hints"])
 
+    for door in configuration["door_patches"]:
+        patch_door(editor, door)
+
     # Text patches
     if "text_patches" in configuration:
         apply_text_patches(editor, configuration["text_patches"])
+    patch_credits(editor)
 
     # Cosmetic patches
     if "cosmetic_patches" in configuration:
